#CCASAnet AIDS at treatment initiation definitions 
#Last Modified:  17JUL2017
#Last Modified by:  M. Giganti


#####################
#AIDS-defining events
#####################
#We are interested in generating a variable that classifies whether a patient has an AIDS-defining event prior to treatment initiation.  There are four primary variables in the database for assessing a patient's clinical status.  The 'aids_y' variable in the basic table, the 'aids_cl_y' variable in the basic table, the 'whostage' variable in the visit table and the 'cdcstage variable in the visit table.  We want to create a composite variable using all of these sources.  (05MAY2014:  'whostage','cdcstage' variables no longer in basic table)

#To generate such a composite variable, the work is divided into three subtasks:  (1) ADE using clinical data in visit table, (2) ADE using aids_cl_y in variable and the corresponding dates (before or after treatment initiation?) basic table, (3) ADE using the aids_y variable and the corresponding dates (before or after treatment initiation?) in basic table.  


#For every patient interaction in the visit table, we can classify a patient as AIDS on not AIDS using the whostage and cdcstage variables.  I used the function previously written by BS.  Next, we need to limit our interactions to just those which occurred prior to patient treatment initiation.  Thus, we exclude all observations which occurred more than 30 days AFTER the patient's initial treatment date.  Using this subsetted dataset, I next look for unique patients who had at least one visit with a ADE.  Create a variable that contains a list of these patients.  Next, I subset the dataset to visits that occurred no more than 365 days BEFORE the patient's treatment initiation and no more than 30 days AFTER treatment initiation. In this subset, I look for patients with at least one confirmed not AIDS visit and create a variable that contains a list of these patients.  I combine these two lists -- if a patient is in both groups, I override with the AIDS classification.  It is important to generate the not AIDS list because we want to differentiate between patients with not AIDS and thus with unknown status. This provides ADE using clinical data in the visit table (1).

#Future consideration:   Should we try to identify patients with no visits preART and their first visit after ART suggests not AIDS?

######################################
#14MAY2014 updated definition for ADE
######################################
#Previously, we used aids_y (AIDSstatus.reported) + aids_cl_y (AIDSstatus.enroll) + clinical staging from visit table (AIDSstatus.visit).  This composite variable was referred to as: 'preART.aids'.
#It is important to note that aids_y and aids_cl_y have different meanings.  aids_cl_y designates an AIDS defining event, while aids_y is AIDS defining events + CD4 < 200. Three sites (argentina, brazil, honduras) populated the aids_y variable only.
#We decided to create two variables to summarize AIDS prior to treatment initiation:
  #One representing clinical aids only (preARTAIDS.clinical)
      #Step 1:  Use clinical staging from visit table (AIDSstatus.visit)
      #Step 2:  If clinical staging from visit table is unknown, use clinical staging from basic table (AIDSstatus.enroll)
      #Step 3:  If clinical staging from visit table is unknown and patient is from Argentina/Honduras, use aids status from basic table (AIDSstatus.reported)
      #Step 4:  If clinical staging from visit table is not AIDS and clinical staging from basic table suggests AIDS, update as AIDS
      #Step 5:  If clinical staging from visit table is not AIDS patient is from Argentina/Honduras and aids status from basic table suggests AIDS, update as AIDS.
	  #Step 6: Update unknowns to not AIDS for brazil patients with aids_y=0.
	  
  #One representing clinical aids + CD4 < 200 (preARTAIDS.all)
  
#####################################################################
#Important note:  The final dataset contains AIDS status for patients who initiated ART only!

######################################
#29JUL2014 update
######################################
#There is a step where we override a patient's clinical AIDS status IF:  (1) they were not AIDS in the visit table, (2) they self-reported AIDS in the basic table and (3) they were from argentina/honduras.

#There was a mistake in the code programming the 2nd condition and thus no changes were made.  This has been updated in this iteration.



#####################################################################
#Reference for how Clinical AIDS is being defined across basic, visit tables
#Written by Giganti Apr2015
#Note: Variables in basic table changed in 2014 - we try to explain how AIDS defined before and after
#####################################################################
#Visit Table
#WHO Stage 1,2or3,4 - Haiti
#CDC Stage A,B,C - Brazil
#CDC Stage A123,B123,C123 - Chile,Honduras,Mexico
#Neither - Argentina,Peru

#Basic Table (old dataset - see Sep2013 for example)
#CDC Stage A123,B123,C123  - Chile
#WHO Stage 1,2or3,4 - Haiti
#WHO Stage 1,2,3,4 - Peru
#Ambiguous aids_y variable - Argentina,Brazil,Chile (cross-tab confirmation of clinical aids only),Haiti,Mexico
#Nothing - Honduras


#Basic Table (new dataset)
#aids_cl_y - Chile, Haiti, Peru (confirmed clinical aids only based on old data)
#aids_cl_y - Argentina, Mexico (ambiguous)
#aids_y - Argentina and Honduras (mix of clinical and CD4 - used to define clinical AIDS because no aids_cl_y variable?)
#Not used for defining clinical AIDS
#aids_y - Brazil (CD4 < 200 only! - not used for clinical AIDS)
#aids_y - Chile (mix of clinical and CD4 - not used for defining clinical AIDS)



####################################################
#Special code to grab Argentina-HF data
#Note that this data is from an archived dataset from 2 years ago
####################################################
#Set working directory
setwd("~/Documents/CCASAnet/Over50")

basic_argentina<-read.csv("../Data/Archived/15JUL2015/basic.csv",header=T)
art_argentina<-read.csv("../Data/Archived/15JUL2015/art.csv",header=T)
follow_argentina<-read.csv("../Data/Archived/15JUL2015/follow.csv",header=T)
visit_argentina<-read.csv("../Data/Archived/15JUL2015/visit.csv",header=T)
lab_cd4_argentina<-read.csv("../Data/Archived/15JUL2015/lab_cd4.csv",header=T)
lab_rna_argentina<-read.csv("../Data/Archived/15JUL2015/lab_rna.csv",header=T)

ReformatArgentina<-function(dat,table="NULL"){
    dat<-dat[dat$site=="argentina",]
    if (table=="basic") {
        dat$center<-with(dat,ifelse(center=="HCE","ar-hc",
        ifelse(center=="SS","ar-ss",
        ifelse(center=="HF","ar-hf",""))))
    }
    return(dat)
}
basic_argentina<-ReformatArgentina(basic_argentina,table="basic")
art_argentina<-ReformatArgentina(art_argentina)
follow_argentina<-ReformatArgentina(follow_argentina)
visit_argentina<-ReformatArgentina(visit_argentina)
lab_cd4_argentina<-ReformatArgentina(lab_cd4_argentina)
####################################################




#Import data
basic_all<-read.csv("../Data/Archived/05MAY2017/basic.csv",header=T)
art_all<-read.csv("../Data/Archived/05MAY2017/art.csv",header=T)
follow_all<-read.csv("../Data/Archived/05MAY2017/follow.csv",header=T)
visit_all<-read.csv("../Data/Archived/05MAY2017/visit.csv",header=T)
lab_cd4_all<-read.csv("../Data/Archived/05MAY2017/lab_cd4.csv",header=T)
lab_rna_all<-read.csv("../Data/Archived/05MAY2017/lab_rna.csv",header=T)


#Combine Argentina data with data from other sites
CombineDat<-function(dat,dat_argentina,table="NULL"){
    #Remove argentina-ss
    dat<-dat[!substr(dat$patient,1,5)=="ar.ss",]
    
    #Remove peds sites
    if ("center"%in%colnames(dat)) {dat<-dat[!dat$center%in% c("pe-hnch","br-ufmg","br-unifesp"),]}
    
    if (table=="basic") dat$center<-as.character(dat$center)
    vars<-colnames(dat_argentina)
    if (table=="art") vars<-vars[vars!=c("art_rs_oth")]
    if (table=="visit") vars<-vars[vars!=c("location")]
    if (table=="follow") vars<-vars[vars!=c("drop_rs_oth")]
    if (table=="lab_rna") vars<-vars[vars!=c("rna_u")]
    
    combined<-merge(dat[,vars],dat_argentina[,vars],by=vars,all=T)
    return(combined)
}
basic<-CombineDat(basic_all,basic_argentina,table="basic")
art<-CombineDat(art_all,art_argentina,table="art")
follow<-CombineDat(follow_all,follow_argentina,table="follow")
visit<-CombineDat(visit_all,visit_argentina,table="visit")
lab_cd4<-CombineDat(lab_cd4_all,lab_cd4_argentina,table="lab_cd4")




#Create a single patient identifier that combines site and patient ID
#Note:  formatC is there to add leading zeros so IDs stay numeric!
SitePatientID<-function(df){
    #df$site.patient<-paste(df$site,"-",formatC(df$patient, width = 6, format = "d", flag = "0"))
    #19SEP2014 - Karu changed the patient variable to closely mirror the site.patient variable I previously generated.
    #Instead of changing ALL of my code,we'll just replace my previous site.patient variable
    df$site.patient<-df$patient
}
#Create unique patient ID for each data table
basic$site.patient<-SitePatientID(basic)
art$site.patient<-SitePatientID(art)
lab_cd4$site.patient<-SitePatientID(lab_cd4)
visit$site.patient<-SitePatientID(visit)

#Date reformatting
    #Reformat other dates from different data tables
    #29JUN2017 -- use baseline_d, not enrol_d
    basic$baseline_dt<-as.Date(basic$baseline_d)
    art$startdate<-as.Date(art$art_sd)
    art$enddate<-as.Date(art$art_ed)
    lab_cd4$cd4_dt<-as.Date(lab_cd4$cd4_d)
    visit$visit_dt<-as.Date(visit$visit_d)


    #Workaround to create date variable
    #Problem because first observation is ""
    temp_aids_dt<-ifelse(basic$aids_d=="","1900-01-01",as.character(basic$aids_d))
    temp_aids_dt<-as.Date(temp_aids_dt)
    basic$aids_dt<-ifelse(temp_aids_dt=="1900-01-01",NA,temp_aids_dt)
    temp_aids_dt<-NULL
    
    temp_aids_cl_dt<-ifelse(basic$aids_cl_d=="","1900-01-01",as.character(basic$aids_cl_d))
    temp_aids_cl_dt<-as.Date(temp_aids_cl_dt)
    basic$aids_cl_dt<-ifelse(temp_aids_cl_dt=="1900-01-01",NA,temp_aids_cl_dt)
    temp_aids_cl_dt<-NULL
 

        
 
#Identify the ART start date for each patient
Artstartdate <- ddply(art, .(site.patient), summarize,FirstARTdate=min(startdate))
 

#Check for lowest CD4 count before ART initiation
lab_temp<-merge(lab_cd4,Artstartdate,by="site.patient")
#Sort by patient,lab date
lab_temp<-with(lab_temp,lab_temp[order(site.patient,cd4_dt),])

lab_temp$ART1lag<-lab_temp$cd4_dt-lab_temp$FirstARTdate

#Nadir CD4
#Does not place lower bound on CD4 date
lab_temp_t<-lab_temp[lab_temp$ART1lag<=7 & is.na(lab_temp$cd4_v)==F & is.na(lab_temp$ART1lag)==F,]
nadirCD4data<-ddply(lab_temp_t,.(site.patient), summarize, nadirCD4=min(cd4_v), nadirCD4_lag=max(ART1lag[cd4_v==min(cd4_v)]))





###################################################
#Substep 1: ADE using clinical data in visit table
###################################################

#Function to combine whostage and cdc staging info
assign.clincalstage<-function(table){
   clinical.stage<-with(table, ifelse(whostage==""&cdcstage=="","",
                               ifelse(whostage==""&cdcstage!="",as.character(cdcstage),
                               ifelse(whostage!=''&cdcstage=="",paste("WHO ",as.character(whostage),sep=""),
                               paste(whostage,cdcstage,sep=";")))))
   return(clinical.stage)
}

#Function to classify staging as AIDS/not AIDS
classify.stage<-function(clinical.stage) {
  ifelse(is.na(clinical.stage)|
           clinical.stage=="","Unknown",
         ifelse(clinical.stage=="A or B"|
                  clinical.stage=="A"|
                  clinical.stage=="A1"|
                  clinical.stage=="A2"|
                  clinical.stage=="A3"|
                  clinical.stage=="B"|
                  clinical.stage=="B1"|
                  clinical.stage=="B2"|
                  clinical.stage=="B3"|
                  clinical.stage=="WHO 1"|
                  clinical.stage=="WHO 2"|
                  clinical.stage=="WHO 3"|
                  clinical.stage=="WHO 2 or 3","not AIDS",
                ifelse(clinical.stage=="C"|
                         clinical.stage=="C1"|
                         clinical.stage=="C2"|
                         clinical.stage=="C3"|
                         clinical.stage=="WHO 4","AIDS","SOMETHING ELSE")))
}

#Run combination and classification of clinical staging for visit table
  visit$clinical.stage<-assign.clincalstage(visit)
  visit$clinical.stage.cat<-classify.stage(visit$clinical.stage)



#Merge visit info with ART start date
#Come up with list of patients with ART start date and an entry in visit table
visit_temp<-merge(visit[,c("site.patient","site","visit_dt","clinical.stage.cat")], Artstartdate,by="site.patient",all.y=TRUE)
visit_temp$indicator<-1
visit_temp$daysfromART<-visit_temp$visit_dt-visit_temp$FirstARTdate

visit.uniquepatients<-unique(visit_temp[,c("site.patient","site")])


#The window between a patient's last visit with an assessment of AIDS and their treatment intiation varies by patient
#A patient's AIDS status is dynamic.  Currently, we are classifying a patient as non-AIDS if their last visit before treatment was non-AIDS, regardless of the length of the window between the last visit date and treatment start date
#The variable - PreART.window tries to limit how recent that visit is, to distinguish between unknown and non-AIDS. 
#Post ART window is the window following the ART initiation date that we use to assess status at time of initiation.
PreART.window<-365
PostART.window<-30




#Find unique patients with any clinical documentation of AIDS before ART
visit.preARTaids<-unique(
  with(visit_temp, visit_temp[which(daysfromART<=PostART.window
				   & clinical.stage.cat=="AIDS"), c("site.patient","indicator")]))
colnames(visit.preARTaids)<-c("site.patient","AIDS")


#Find patients with non-AIDS status at time of ART initiation
#Want to identify all cases where patient has documentation of 'not-AIDS' between the pre-ART window and post-ART window
visit.preARTnoaids<-unique(
  with(visit_temp, visit_temp[which(daysfromART>=-PreART.window 
  				   & daysfromART<=PostART.window
				   & clinical.stage.cat=="not AIDS"),c("site.patient","indicator")]))
colnames(visit.preARTnoaids)<-c("site.patient","notAIDS")

visit_temp3<-merge(visit.uniquepatients ,visit.preARTaids,by="site.patient", all=T)
visit_temp2<-merge(visit_temp3, visit.preARTnoaids,,by="site.patient",all=T)


#Classify patients as AIDS if at least one pre-ART visit with ADE, classify as non-AIDS if all pre-ART visits are non-AIDS
#Assign patients with no visits as unknown AIDS status for the 'visit' variable
visit_temp2$AIDSstatus.visit<-with(visit_temp2,	
	    ifelse(AIDS==1 & is.na(AIDS)==FALSE,"AIDS",
	    ifelse(notAIDS==1 & is.na(notAIDS)==FALSE,"not AIDS",
	   	"Unknown")))				 
		

AIDSstatus.visit<-visit_temp2[,c("site.patient","AIDSstatus.visit")]




#######################################################################################################################################
#Substep 2:  ADE using the aids_y variable and the corresponding dates (before or after treatment initiation?) in basic table
#######################################################################################################################################
#######################################################################################################################################
#Substep 3:  ADE using aids_cl_y in variable and the corresponding dates (before or after treatment initiation?) basic table
#######################################################################################################################################

AIDSstatus.basic<-merge(basic[,c("site.patient","patient","site","baseline_dt","aids_y","aids_dt","aids_cl_y","aids_cl_dt")], 
     Artstartdate,all.y=TRUE)

						
 
#Classify AIDS status at treatment initiation using aids_y variable
#WTD:  How to classify non-AIDS patients who enroll after ART initiation
#WTD:  How to classify non-AIDS patients who enroll more than year before ART initiation
#WTD:  xx patients with aids_d after ART date -Unknown or not ART?
AIDSstatus.basic$AIDSstatus.reported<-
	with(AIDSstatus.basic,
		ifelse(is.na(aids_y)=="TRUE" |  aids_y==9, "Unknown",
		ifelse(aids_y==1 & is.na(aids_dt)=="FALSE" & aids_dt <= (FirstARTdate+30), "AIDS",
		ifelse(aids_y==1 & is.na(aids_dt)=="FALSE" & aids_dt > (FirstARTdate+30), "Unknown",
		ifelse(aids_y==1 & is.na(aids_dt)=="TRUE"  & baseline_dt <= (FirstARTdate+30), "AIDS",		
		ifelse(aids_y==1 & is.na(aids_dt)=="TRUE"  & baseline_dt> (FirstARTdate+30), "Unknown",
		ifelse(aids_y==0 & baseline_dt<=(FirstARTdate+30) & baseline_dt>=(FirstARTdate-PreART.window), "not AIDS",
        ifelse(aids_y==0 & baseline_dt<=(FirstARTdate+30) & baseline_dt<(FirstARTdate-PreART.window), "Unknown",
		ifelse(aids_y==0 & baseline_dt>(FirstARTdate-30), "Unknown",
		"Unknown")))))))))
#Classify AIDS status at treatment initiation using aids_cl_y variables in basic
AIDSstatus.basic$AIDSstatus.enroll<-
	with(AIDSstatus.basic,
		ifelse(is.na(aids_cl_y)=="TRUE" |  aids_cl_y==9, "Unknown",
		ifelse(aids_cl_y==1 & is.na(aids_cl_dt)=="FALSE" & aids_cl_dt <= (FirstARTdate+30), "AIDS",
		ifelse(aids_cl_y==1 & is.na(aids_cl_dt)=="FALSE" & aids_cl_dt > (FirstARTdate+30), "Unknown",
		ifelse(aids_cl_y==1 & is.na(aids_cl_dt)=="TRUE"  & baseline_dt <= (FirstARTdate+30), "AIDS",		
		ifelse(aids_cl_y==1 & is.na(aids_cl_dt)=="TRUE"  & baseline_dt> (FirstARTdate+30), "Unknown",
		ifelse(aids_cl_y==0 & baseline_dt<=(FirstARTdate+30) & baseline_dt>=(FirstARTdate-PreART.window), "not AIDS",
        ifelse(aids_cl_y==0 & baseline_dt<=(FirstARTdate+30) & baseline_dt<(FirstARTdate-PreART.window), "Unknown",
		ifelse(aids_cl_y==0 & baseline_dt>(FirstARTdate-30), "Unknown",
		"Unknown")))))))))
		

AIDSstatus.basic<-AIDSstatus.basic[,c("site.patient","patient","site","AIDSstatus.reported","AIDSstatus.enroll")]




########################################################################################							
###Clinical AIDS definition using clinical staging from visit table + aids_cl_y + aids_y
########################################################################################

AIDSstatus_temp<-merge(AIDSstatus.basic,AIDSstatus.visit,by=c("site.patient"),all=T)
AIDSstatus<-merge(AIDSstatus_temp,nadirCD4data,by=c("site.patient"),all=T)
AIDSstatus$nadirCD4cat<-with(AIDSstatus,ifelse(nadirCD4<=200 & is.na(nadirCD4)==F,"LT 200",
                            ifelse(nadirCD4>200 & abs(nadirCD4_lag)<=180 & is.na(nadirCD4)==F & is.na(nadirCD4_lag)==F,"GT 200",
                            "Unknown")))

#Step 1:  Use clinical staging from visit table (AIDSstatus.visit)
#Step 2:  If clinical staging from visit table is unknown, use clinical staging from basic table (AIDSstatus.enroll)
#Step 3:  If clinical staging from visit table is unknown and patient is from Argentina/Honduras, use aids status from basic table (AIDSstatus.reported)
#Step 4:  If clinical staging from visit table is not AIDS and clinical staging from basic table suggests AIDS, update as AIDS
#Step 5:  If clinical staging from visit table is not AIDS patient is from Argentina/Honduras and aids status from basic table 
#Step 6: Update unknowns to not AIDS for brazil patients with aids_y=0							
#Steps 1+ 2
AIDSstatus$preARTAIDS.clinical<- with(AIDSstatus, ifelse(AIDSstatus.visit=="Unknown", AIDSstatus.enroll, AIDSstatus.visit))
#Step 3
AIDSstatus$preARTAIDS.clinical<- with(AIDSstatus, ifelse(preARTAIDS.clinical=="Unknown" & site %in% c("argentina","honduras"), AIDSstatus.reported, preARTAIDS.clinical))
#Steps 4+ 5 - Replace non-AIDS with AIDS if AIDS for any visit
AIDSstatus$preARTAIDS.clinical<-with(AIDSstatus, ifelse(preARTAIDS.clinical=="not AIDS" & AIDSstatus.enroll=="AIDS", "AIDS",preARTAIDS.clinical))
#29JUL2014 - there was a mistake in the code below - fixed
AIDSstatus$preARTAIDS.clinical<-with(AIDSstatus, ifelse(preARTAIDS.clinical=="not AIDS" & AIDSstatus.reported=="AIDS"  & site %in% c("argentina","honduras"), "AIDS",preARTAIDS.clinical))					
#update unknowns to not AIDS for brazil patients with aids_y=0. 
AIDSstatus$preARTAIDS.clinical<- with(AIDSstatus, ifelse(preARTAIDS.clinical=="Unknown" & site %in% c("brazil") & AIDSstatus.reported=="not AIDS", AIDSstatus.reported, preARTAIDS.clinical))



########################################################################################							
###AIDS definition using clinical staging from visit table + aids_cl_y + aids_y + nadir CD4  < 200
########################################################################################
#Create composite variable of aids_y (AIDSstatus.reported) + aids_cl_y (AIDSstatus.enroll) + clinical staging from visit table (AIDSstatus.visit).  
							#Previously referred to as:  'preART.aids'
							#Use data from visit table as primary source
							#Replace unknowns with data from updated clinical status variable in basic
							#Replace remaining unknowns with updated aids_y variable

AIDSstatus$AIDSstatus.composite<- with(AIDSstatus, ifelse(AIDSstatus.visit=="Unknown", AIDSstatus.enroll, AIDSstatus.visit))
AIDSstatus$AIDSstatus.composite<- with(AIDSstatus, ifelse(AIDSstatus.composite=="Unknown", AIDSstatus.reported, AIDSstatus.composite))
#Replace non-AIDS with AIDS if AIDS for any visit
AIDSstatus$AIDSstatus.composite<-with(AIDSstatus, ifelse(AIDSstatus.composite=="not AIDS" & 
							    (AIDSstatus.reported=="AIDS" | AIDSstatus.enroll=="AIDS"), "AIDS",AIDSstatus.composite))	
                                
              
	 
#Merge nadir CD4 counts for each patient
AIDSstatus$preARTAIDS.all<-with(AIDSstatus,
                                    ifelse(AIDSstatus.composite=="AIDS" & nadirCD4cat=="LT 200", "AIDS",
                                    ifelse(AIDSstatus.composite=="AIDS" & nadirCD4cat=="GT 200", "AIDS",
                                    ifelse(AIDSstatus.composite=="AIDS" & nadirCD4cat=="Unknown", "AIDS",
                                    ifelse(AIDSstatus.composite=="not AIDS" & nadirCD4cat=="LT 200", "AIDS",
                                    ifelse(AIDSstatus.composite=="not AIDS" & nadirCD4cat=="GT 200", "not AIDS",
                                    ifelse(AIDSstatus.composite=="not AIDS" & nadirCD4cat=="Unknown", "not AIDS",
                                    ifelse(AIDSstatus.composite=="Unknown" & nadirCD4cat=="LT 200", "AIDS",
                                    ifelse(AIDSstatus.composite=="Unknown" & nadirCD4cat=="GT 200", "Unknown",
                                    ifelse(AIDSstatus.composite=="Unknown" & nadirCD4cat=="Unknown", "Unknown",
                                    "Not ART"))))))))))



  

#Final N x 4 matrix containing relevant patient info                     
AIDSstatus<-AIDSstatus[,c("site","patient","preARTAIDS.clinical","preARTAIDS.all")]


save(AIDSstatus,file="CCASAnetAIDSstatus.Rda")
