#CCASAnet data
#Over50 analysis
#This code prepares analysis dataset for CCASAnet data
#Giganti
#Start Date:  09AUG2015



#Current run time:  ~10 minutes

#This is frankly silly, but the packages plyr and Hmisc do not work well together
#The code below uses plyr and Hmisc has not yet been loaded, so it should work fine
#However, if you re-run this code or try to take advantage of cache, you will have a bad time
#To resolve this problem, I load the trouble packages and then detach!
suppressPackageStartupMessages(library(rms))
detach(package:rms)
detach(package:Hmisc)

require(plyr)

setwd("~/Documents/CCASAnet/Over50")


#Use function to combine ADE information across all sites
source('CCASAnet ADE definition R code.R', chdir = FALSE)
#load("CCASAnetAIDSstatus.Rda")



#########################
#Processing phase of code
########################
#Import data
#Format data

#Set Freeze date for initiation
	FreezeDate<-as.Date('2017-01-01')


#Set earliest possible ART start date - HAART didn't exist before 1996!
	EarliestARTDate<-as.Date('1996-01-01')


#Import data
    basic_all<-read.csv("../Data/Archived/05MAY2017/basic.csv",header=T)
    art_all<-read.csv("../Data/Archived/05MAY2017/art.csv",header=T)
    follow_all<-read.csv("../Data/Archived/05MAY2017/follow.csv",header=T)
    visit_all<-read.csv("../Data/Archived/05MAY2017/visit.csv",header=T)
    lab_cd4_all<-read.csv("../Data/Archived/05MAY2017/lab_cd4.csv",header=T)
    lab_rna_all<-read.csv("../Data/Archived/05MAY2017/lab_rna.csv",header=T)


#Special code to grab Argentina-HF data
    basic_argentina<-read.csv("../Data/Archived/15JUL2015/basic.csv",header=T)
    art_argentina<-read.csv("../Data/Archived/15JUL2015/art.csv",header=T)
    follow_argentina<-read.csv("../Data/Archived/15JUL2015/follow.csv",header=T)
    visit_argentina<-read.csv("../Data/Archived/15JUL2015/visit.csv",header=T)
    lab_cd4_argentina<-read.csv("../Data/Archived/15JUL2015/lab_cd4.csv",header=T)


    ReformatArgentina<-function(dat,table="NULL"){
        dat<-dat[dat$site=="argentina",]
        if (table=="basic") {
            dat$center<-with(dat,ifelse(center=="HCE","ar-hc",
            ifelse(center=="SS","ar-ss",
            ifelse(center=="HF","ar-hf",""))))
        }
        return(dat)
    }
    basic_argentina<-ReformatArgentina(basic_argentina,table="basic")
    art_argentina<-ReformatArgentina(art_argentina)
    follow_argentina<-ReformatArgentina(follow_argentina)
    visit_argentina<-ReformatArgentina(visit_argentina)
    lab_cd4_argentina<-ReformatArgentina(lab_cd4_argentina)
    lab_rna_argentina<-ReformatArgentina(lab_rna_argentina)


    CombineDat<-function(dat,dat_argentina,table="NULL"){
        #Remove argentina-ss
        dat<-dat[!substr(dat$patient,1,5)=="ar.ss",]
        
        #Remove peds sites
        if ("center"%in%colnames(dat)) {dat<-dat[!dat$center%in% c("pe-hnch","br-ufmg","br-unifesp"),]}
        
        
        if (table=="basic") dat$center<-as.character(dat$center)
        
        #Temp -- remove Peru obs without VL date
        if (table=="lab_rna") dat<-dat[dat$rna_d!="",]
        
        vars<-colnames(dat_argentina)
        if (table=="art") vars<-vars[vars!=c("art_rs_oth")]
        if (table=="visit") vars<-vars[vars!=c("location")]
        if (table=="follow") vars<-vars[vars!=c("drop_rs_oth")]
        if (table=="lab_rna") vars<-vars[vars!=c("rna_u")]
        
        combined<-merge(dat[,vars],dat_argentina[,vars],by=vars,all=T)
        return(combined)
    }
    basic<-CombineDat(basic_all,basic_argentina,table="basic")
    art<-CombineDat(art_all,art_argentina,table="art")
    follow<-CombineDat(follow_all,follow_argentina,table="follow")
    visit<-CombineDat(visit_all,visit_argentina,table="visit")
    lab_cd4<-CombineDat(lab_cd4_all,lab_cd4_argentina,table="lab_cd4")
    lab_rna<-CombineDat(lab_rna_all,lab_rna_argentina,table="lab_rna")



#Create a single patient identifier that combines site and patient ID
    SitePatientID<-function(df){
      df$site.patient<-as.character(df$patient)
    }
#Create unique patient ID for each data table
	basic$site.patient<-SitePatientID(basic)
	art$site.patient<-SitePatientID(art)
	follow$site.patient<-SitePatientID(follow)
	lab_cd4$site.patient<-SitePatientID(lab_cd4)
	visit$site.patient<-SitePatientID(visit)
	lab_rna$site.patient<-SitePatientID(lab_rna)
	AIDSstatus$site.patient<-SitePatientID(AIDSstatus)

#Date reformatting
    basic$birth_dt<-as.Date(basic$birth_d)
    art$startdate<-as.Date(art$art_sd)
    art$enddate<-as.Date(art$art_ed)
    basic$baseline_dt<-as.Date(basic$baseline_d)
	follow$lastalive_dt<-as.Date(follow$l_alive_d)
    lab_cd4$cd4_dt<-as.Date(lab_cd4$cd4_d)
    lab_rna$rna_dt<-as.Date(lab_rna$rna_d)
    visit$visit_dt<-as.Date(visit$visit_d)


    #Workaround to create date variable
    #Problem because first observation is ""
    temp_aids_dt<-ifelse(basic$aids_d=="","1900-01-01",as.character(basic$aids_d))
    temp_aids_dt<-as.Date(temp_aids_dt)
    basic$aids_dt<-ifelse(temp_aids_dt=="1900-01-01",NA,temp_aids_dt)
    temp_aids_dt<-NULL
    
    temp_aids_cl_dt<-ifelse(basic$aids_cl_d=="","1900-01-01",as.character(basic$aids_cl_d))
    temp_aids_cl_dt<-as.Date(temp_aids_cl_dt)
    basic$aids_cl_dt<-ifelse(temp_aids_cl_dt=="1900-01-01",NA,temp_aids_cl_dt)
    temp_aids_cl_dt<-NULL
                  
    temp_death_dt<-ifelse(follow$death_d=="","1900-01-01",as.character(follow$death_d))
    temp_death_dt<-as.Date(temp_death_dt)
    follow$death_dt<-ifelse(temp_death_dt=="1900-01-01",NA,temp_death_dt)
    temp_death_dt<-NULL


    #Limit data to just those prior to freeze date
    #Modify enddate, last_alive_dt, and death_dt variables according to this freeze date
    art<-art[art$startdate<FreezeDate & is.na(art$startdate)==F,]
    lab_cd4<-lab_cd4[lab_cd4$cd4_dt<FreezeDate & is.na(lab_cd4$cd4_dt)==F,]
    lab_rna<-lab_rna[lab_rna$rna_dt<FreezeDate & is.na(lab_rna$rna_dt)==F,]
    visit<-visit[visit$visit_dt<FreezeDate & is.na(visit$visit_dt)==F,]
    art$enddate<-as.Date(ifelse(art$enddate<FreezeDate,art$enddate,NA),origin="1970-01-01")
    follow$death_y<-ifelse(follow$death_dt>FreezeDate & is.na(follow$death_dt)==F,0,follow$death_y)
    follow$death_dt<-as.Date(ifelse(follow$death_dt>=FreezeDate & is.na(follow$death_dt)==F,FreezeDate-1,follow$death_dt),origin="1970-01-01")
    follow$lastalive_dt<-as.Date(ifelse(follow$lastalive_dt<FreezeDate ,follow$lastalive_dt,FreezeDate-1),origin="1970-01-01")






################################################################################
#Begin working with individual datasets in order to generate key analysis variables
################################################################################

###############
#Follow Dataset
###############

#Mexico,Chile do not routinely fill out follow form during data collection.  This last visit date is typically the last visit date in the follow table, but not always (Brazil had alot of discordancy in a 2015 version of database + Argentina has some discordancy in 2016 version)
DerivedLastVisitDateFunction<-function(){
    
    visit.short<-cbind(visit[,c("site.patient","visit_dt")],"visit")
    cd4.short<-cbind(lab_cd4[,c("site.patient","cd4_dt")],"cd4")
    vl.short<-cbind(lab_rna[,c("site.patient","rna_dt")],"rna")
    drug.short<-cbind(art[,c("site.patient","startdate")],"artstart")
    drug.short2<-cbind(art[,c("site.patient","enddate")],"artend")
    
    drop.short<-with(follow,cbind(follow[drop_y==1 & is.na(drop_y)==F &lastalive_dt<=FreezeDate & is.na(lastalive_dt)==F,c("site.patient","lastalive_dt")],"drop"))
    colnames(visit.short)<-colnames(cd4.short)<-colnames(vl.short)<-colnames(drug.short)<-colnames(drug.short2)<-colnames(drop.short)<-c("site.patient","date","table")
    
    all.short<-rbind(visit.short,
    cd4.short,
    vl.short,
    drug.short,
    drug.short2,
    drop.short
    )
    all.short<-all.short[is.na(all.short$date)==F,]
    
    LastVisitDate <- ddply(all.short, .(site.patient), summarize,LastVisitDate=max(date))
    return(LastVisitDate)
}


#The last_visit_dt currently in follow table tends to be a later date than the derived LastVisitDate.  We will continue using that for now, but future analyses should continue to compare the two dates and determine which is most appropriate
    #DerivedLastVisitDate<-DerivedLastVisitDateFunction()
    #follow<-merge(follow,DerivedLastVisitDate,by="site.patient",all=T)




#Creating analysis variables
#Censor date
    follow$censor_dt<-ifelse(follow$death_y==1 & is.na(follow$death_dt)==F, follow$death_dt,follow$lastalive_dt)
    #follow$censor_dt<-ifelse(follow$death_y==1 & is.na(follow$death_dt)==F, follow$death_dt,follow$LastVisitDate)
    follow$censor_dt<-as.Date(follow$censor_dt,origin="1970-01-01")


#Create truncated dataset to merge later
    follow.short<-follow[,c("site.patient","death_y","censor_dt")]




###########
##ART
###########


#ARV classification
	art<-with(art,art[order(site.patient,startdate,enddate),])


#Noticed some have ART ID if 'OTHER'  This 5 character value is messing up rest of code written for 3 character values. (09AUG2015)
	art$art_id<-gsub("OTHER","OTH",art$art_id)

	ARV1<- substr(art$art_id,1,3)
	ARV2<- substr(art$art_id,5,7)
	ARV3<- substr(art$art_id,9,11)
	ARV4<- substr(art$art_id,13,15)
	ARV5<- substr(art$art_id,17,19)
	ARV6<- substr(art$art_id,21,23)
	ARV7<- substr(art$art_id,25,27)
	ARV8<- substr(art$art_id,29,31)

	ARVs<-cbind(ARV1,ARV2,ARV3,ARV4,ARV5,ARV6,ARV7,ARV8)
	NRTI<-PI<-NNRTI<-EI<-FI<-II<-CCR5<-OTHER<-rep(0,length(art$art_id))

	for (i in 1:8){
	    #MVC not in codebook - categorized as maraviroc (MRV) / consistent with Karu
	    #RAL not in codebook - categorized as IL (Raltegravir) / consistent with Karu
	    #ENF not in codebook - categorized as FI (T20) / consistent with Karu
	    #ETR not in codebook - categorized as Etravirine (ETV) / consistent with Karu 
	    #CAP not in codebook - From regimen spreadsheet, Assume that CAP is capravirine, an investigational NNRTI
		#VIC not in codebook -- E-mail from Karu 20OCT2016 confirmed it is CCR5
	    #Believe PBO represents placebo and should not get a +1
	    NRTI<-ifelse (ARVs[,i] %in% c("3TC","ABC","AZT","D4T","DDC","DDI","FTC","TDF"), NRTI+1,NRTI)
	    PI<-ifelse (ARVs[,i] %in% c("APV","ATV","DRV","FPV","IDV","NFV","LPV","SQV","TPV"),PI+1,
	    ifelse (ARVs[,i] %in% c("RTV"),PI+0.5,PI))
	    NNRTI<-ifelse (ARVs[,i] %in% c("DLV","EFV","ETV","NVP","RPV","ETR","CAP"),NNRTI+1,NNRTI)
	    EI<-ifelse (ARVs[,i] %in% c("MRV","MVC"),EI+1,
	    ifelse(ARVs[,i] %in% c("PBO"),EI,
	    EI))
	    FI<-ifelse (ARVs[,i] %in% c("T20","ENF"),FI+1,FI)
	    II<-ifelse (ARVs[,i] %in% c("DTG","EVG","RGV","RAL"),II+1,II)
	    CCR5<-ifelse (ARVs[,i] %in% c("VIC"),CCR5+1,CCR5)
	}
	OTHER<-EI+FI+II+CCR5


	OneMat<-data.frame(NRTI=NRTI, NNRTI=NNRTI,PI=PI,OTHER=OTHER)
	OneMat$ClassCount<-with(OneMat,paste(NRTI,"-",NNRTI,"-",PI,"-",OTHER,sep=""))


	source('~/Documents/CCASAnet/Over50/ARV reclassification R code.R', chdir = FALSE)
	art$regimen<-ARVreclassification(OneMat)

    art$t20ccr5ii1ii2<-with(art,t20+ccr5+ii1+ii2)


#Find ART start date
#Strategy: Restrict dataset to just first ART observation
#Always confirm that art does not need to be ordered, especially since we are using cbind() and ddply later
	art<-cbind(art,OneMat)
	art_temp <- ddply(art, .(site.patient), summarize,FirstARTdate=min(startdate))
	art_temp<-merge(art_temp,art,by.x=c("site.patient","FirstARTdate"),by.y=c("site.patient","startdate"),all.x=T)
	Artstartdate<-art_temp[,c("site.patient","FirstARTdate","regimen","nrti","nnrti","pi","rtv_drug","t20ccr5ii1ii2","art_id","art_sd_a")]
	names(Artstartdate)<-c("site.patient","FirstARTdate","FirstARVclass","FirstNRTI","FirstNNRTI","FirstPI","FirstRTV","FirstOTHER","FirstART","FirstARTExact")


#Simplify ARV class variable: NNRTI,Boosted PI, nonHAART,other
#Patients with NNRTI or PI AND Other being sent to other
	Artstartdate$FirstARVclass<-toupper(Artstartdate$FirstARVclass)
	Artstartdate$FirstARVclass<-with(Artstartdate, as.factor(ifelse(FirstARVclass=="NNRTI","NNRTI",
														ifelse(FirstARVclass=="BOOSTED PI","BOOSTED PI",
														ifelse(FirstARVclass=="3 NRTI","3 NRTI",
														ifelse(FirstARVclass=="UNBOOSTED PI","UNBOOSTED PI",
														ifelse(FirstARVclass=="PI","UNBOOSTED PI",
														ifelse(FirstARVclass=="OTHER","OTHER",
														ifelse(FirstARVclass %in% c("NONHAART","NON HAART","NON-HAART"),"nonHAART",
														NA)))))))))

	#Add first start date to art
	art<-merge(art,Artstartdate,by.x=c("site.patient"),by.y=c("site.patient"))




########################################################
#In this particular analysis, we are interested in time since HAART initiation specifically
#Thus, we want to start the clock at time of HAART
#Below, we generate a variable not used in other analysis
#Will want to classify patients who start nonHAART as non-naive
########################################################
	art_HAARTonly<-art[art$regimen!="non-HAART",]
	HAART_temp <- ddply(art_HAARTonly, .(site.patient), summarize,FirstHAARTdate=min(startdate))
	HAART_temp<-merge(HAART_temp,art_HAARTonly,by.x=c("site.patient","FirstHAARTdate"),by.y=c("site.patient","startdate"),all.x=T)
	HAARTstartdate<-HAART_temp[,c("site.patient","FirstHAARTdate","regimen","art_id","nrti","nnrti","pi","rtv_drug","t20ccr5ii1ii2","art_sd_a")]
	names(HAARTstartdate)<-c("site.patient","FirstHAARTdate","FirstHAARTclass","FirstHAART","FirstHAARTNRTI","FirstHAARTNNRTI","FirstHAARTPI","FirstHAARTRTV",
	"FirstHAARTOTHER","FirstHAARTExact")

#Simplify ARV class variable: NNRTI,Boosted PI, nonHAART,other
    HAARTstartdate$FirstHAARTclass<-toupper(HAARTstartdate$FirstHAARTclass)
	HAARTstartdate$FirstHAARTclass<-with(HAARTstartdate, 
										as.factor(ifelse(FirstHAARTclass=="NNRTI","NNRTI",
													ifelse(FirstHAARTclass=="BOOSTED PI","BOOSTED PI",
													ifelse(FirstHAARTclass=="3 NRTI","OTHER",
													ifelse(FirstHAARTclass=="UNBOOSTED PI","OTHER",
													ifelse(FirstHAARTclass=="PI","OTHER",
													ifelse(FirstHAARTclass=="OTHER","OTHER",
													ifelse(FirstHAARTclass %in% c("NONHAART","NON HAART","NON-HAART"),"nonHAART",
													NA)))))))))

	art<-with(art,art[order(site.patient,startdate,enddate),])



######################################################################
#Substantial changes to how we define HAARTstop,HAART change (19FEB2015)
######################################################################
#Compare art entry with next entry to check for regimen gap or treatment change
    artorig<-art[,c("site.patient","art_id","startdate","enddate")]
    artnext<-rbind(artorig[2:dim(artorig)[1],],artorig[1,])[,c("site.patient","art_id","startdate")]
    colnames(artnext)<-c("site.patient.next","art_id.next","startdate.next")
    artgap_temp0<-cbind(artorig,artnext)

    artgap_temp0$StopIndicator<-with(artgap_temp0,ifelse(site.patient!=site.patient.next, "No change",
    ifelse(art_id==art_id.next & enddate==startdate.next,"No change, 2 entries",
    ifelse(art_id==art_id.next & (enddate+14)>startdate.next,"Gap <14",
    ifelse(art_id==art_id.next & enddate!=startdate.next,"Gap",
    ifelse(art_id!=art_id.next & (enddate+14)>startdate.next,"ImmediateRegimenSwitch",
    ifelse(art_id!=art_id.next & (enddate+14)<=startdate.next,"DelayedRegimenSwitch","Error")))))))

#19FEB2015 We may not be interested in non-stoppage or changes. Big change: workaround to remove the "no change,2 entries", "Gap <14" entries.
#Affects about 800+ obs
    ShortGap<-artgap_temp0[artgap_temp0$StopIndicator%in%c("Gap <14","No change, 2 entries"),c("site.patient","startdate","startdate.next")]
    colnames(ShortGap)<-c("site.patient","oldstartdate","startdate")

#Some patients have consecutive entries with no change or small gaps.  #Need to work around
    counter<-0
    ids<-osd<-srd<-NULL
    for (i in 2:dim(ShortGap)[1]){
        if (i==2){
            counter<-counter+1
            #Only assign old start date once
            osd[counter]<-ShortGap$oldstartdate[1]
            ids[counter]<-ShortGap$site.patient[1]
            #Update startdate
            srd[counter]<-ShortGap$startdate[1]
            
        }
        if (ShortGap$site.patient[i]!=ShortGap$site.patient[i-1] | ShortGap$oldstartdate[i]>(14+ShortGap$startdate[i-1])) {
            counter<-counter+1
            #Only assign old start date once
            osd[counter]<-ShortGap$oldstartdate[i]
            
        }
        ids[counter]<-ShortGap$site.patient[i]
        #Update startdate
        srd[counter]<-ShortGap$startdate[i]
        
    }
    ShortGap_updated<-data.frame(ids,as.Date(osd,origin="1970-01-01"),as.Date(srd,origin="1970-01-01"))
    colnames(ShortGap_updated)<-c("site.patient","oldstartdate","startdate")


    #Finish update by replace startdate with "true" startdate
    artgap_temp<-merge(artgap_temp0,ShortGap_updated,by=c("site.patient","startdate"),all=T)
    artgap_temp$startdate<-as.Date(with(artgap_temp,ifelse(is.na(oldstartdate)==F,oldstartdate,startdate)),origin="1970-01-01")


    artgap_temp$oldstartdate<-NULL
    artgap_temp<-artgap_temp[!artgap_temp$StopIndicator%in%c("Gap <14","No change, 2 entries"),]


    #Find minimum stoppage date (among real stoppages) and first change date
    #First gap or switch
    artgap_firststop <- ddply(artgap_temp, .(site.patient), summarize,FirstARTdate=min(startdate))
    #First switch
    artgap_firstchange<- ddply(artgap_temp[artgap_temp$StopIndicator%in%c("DelayedRegimenSwitch","ImmediateRegimenSwitch"),], .(site.patient), summarize,HAARTFirstChange_dt=min(startdate.next))
    #22MAY2015  - First interuption > 14 days
    artgap_firstinterrupt<- ddply(artgap_temp[!artgap_temp$StopIndicator%in%c("ImmediateRegimenSwitch"),], .(site.patient), summarize,ARTdate=min(startdate))


    #Combine stoppage dates/reasons together
    artgap_firststop2<-merge(artgap_firststop,artgap_temp[,c("site.patient","startdate","enddate","StopIndicator")],by.x=c("site.patient","FirstARTdate"),by.y=c("site.patient","startdate"),all.x=T)
    colnames(artgap_firststop2)<-c("site.patient","FirstARTdate","HAARTFirstStop_dt","FirstStopIndicator")

    artgap_firstinterrupt2<-merge(artgap_firstinterrupt,artgap_temp[,c("site.patient","startdate","enddate","StopIndicator")],by.x=c("site.patient","ARTdate"),by.y=c("site.patient","startdate"),all.x=T)
    artgap_firstinterrupt3<-merge(artgap_firstinterrupt2,art[,c("site.patient","startdate","art_rs")],by.x=c("site.patient","ARTdate"),by.y=c("site.patient","startdate"),all.x=T)
    colnames(artgap_firstinterrupt3)<-c("site.patient","garbo","HAARTFirstInterrupt_dt","FirstInterruptIndicator","InterruptionReason")

    artgap_firstinterrupt3<-artgap_firstinterrupt3[,c("site.patient","HAARTFirstInterrupt_dt","FirstInterruptIndicator","InterruptionReason")]

    artgap1<-merge(artgap_firststop2,artgap_firstchange,by="site.patient",all=T)
    artgap<-merge(artgap1,artgap_firstinterrupt3,by="site.patient",all=T)


    ARTSummaryData_temp<-merge(Artstartdate,artgap,by=c("site.patient","FirstARTdate"),all=T)
    ARTSummaryData<-merge(ARTSummaryData_temp,HAARTstartdate,by=c("site.patient"),all=T)




#############
####Labs#####
#############	
###########################
#Check for first CD4 count
############################
	lab_temp<-merge(lab_cd4,HAARTstartdate,by="site.patient")
	lab_temp$ART1lag<-lab_temp$cd4_dt-lab_temp$FirstHAARTdate

#Nadir CD4 (08SEP2013 addition)
#Does not place lower bound on CD4 date
	lab_temp_t<-lab_temp[lab_temp$ART1lag<=7 & is.na(lab_temp$cd4_v)==F & is.na(lab_temp$ART1lag)==F,]
	nadirCD4data<-ddply(lab_temp_t,.(site.patient), summarize, nadirCD4=min(cd4_v), nadirCD4_lag=max(ART1lag[cd4_v==min(cd4_v)]),nadirCD4_dt=max(cd4_dt[cd4_v==min(cd4_v)]))


#Time since initiation
#Restrict to those labs within baseline CD4 window  -180 - +7 days within initiation
	lab_temp2<-lab_temp_t[lab_temp_t$ART1lag<=7 & lab_temp_t$ART1lag>-181 & is.na(lab_temp_t$ART1lag)==F,]
#How to choose 'best lab (per 11/11 convo with BS):
    #1 - Look for lab closest to start date BEFORE initiation
    #2 - If no lab within 180 days before initiation, take first lab within 7 days
#Create garbo variable to make this happen
#Take abs value of all variables, add 180 days to labs after initiation
#Grab the minimum
	lab_temp2$cd4window_temp<-as.numeric(abs(lab_temp2$ART1lag)+((lab_temp2$ART1lag)>0)*180)
	BaselineCD4data<-ddply(lab_temp2,.(site.patient), summarize, BaselineCD4=max(cd4_v[cd4window_temp==min(cd4window_temp)]),BaselineCD4_lag=ART1lag[cd4window_temp==min(cd4window_temp)],BaselineCD4_dt=cd4_dt[cd4window_temp==min(cd4window_temp)])



#Function to determine CD4 count at a specific timepoint AFTER HAART initiation
    PostHAARTCD4s<-function(timepoint,window,label){
        window.lower<-timepoint-window
        window.upper<-timepoint+window
        #How to choose 'best lab' for post-HAART (Giganti)
        #Identify all labs in window of timepoint
        #Grab the closest to timepoint
        #Need to jitter it a little so that we can distinguish ties before (.99) and after (0.01) timepoint
        #In case of tie, take the lab AFTER timepoint
        
        lab_temp3<-lab_temp[lab_temp$ART1lag<=window.upper & lab_temp$ART1lag>window.lower & is.na(lab_temp$ART1lag)==F& is.na(lab_temp$cd4_v)==F,]
        lab_temp3$cd4window_temp1<-as.numeric((lab_temp3$ART1lag - timepoint))
        lab_temp3$cd4window_temp<-as.numeric(abs(lab_temp3$ART1lag - timepoint+.01))
        
        WindowCD4data<-ddply(lab_temp3,.(site.patient), summarize, WindowCD4=(cd4_v[cd4window_temp==min(cd4window_temp)]), WindowCD4_lag=(cd4window_temp1[cd4window_temp==min(cd4window_temp)]))
        names(WindowCD4data)<-c("site.patient",label,paste(label,".lag",sep=""))
        return(WindowCD4data)
    }
#CD4s at 6,12,24 months
    CD4.at.6months<-PostHAARTCD4s(timepoint=180,window=90,label="CD4.6")
    CD4.at.12months<-PostHAARTCD4s(timepoint=365,window=90,label="CD4.12")
    CD4.at.24months<-PostHAARTCD4s(timepoint=730,window=90,label="CD4.24")
    CD4.PostBaseline_temp<-merge(CD4.at.6months,CD4.at.12months,by="site.patient",all=T)
    CD4.PostBaseline<-merge(CD4.PostBaseline_temp,CD4.at.24months,by="site.patient",all=T)



###########################
#First VL + VL Failure
###########################
#There is inconsistency in identifying VL failures.  Some sites use negative numbers, some will use the exact detection limit/minus 1.
#Giganti decided to use below 400 (24JUL2014)
	lab_rna$undetect.vl<-ifelse(lab_rna$rna_v<=400,1,0)


	labrna_temp<-merge(lab_rna[,c("site.patient","rna_dt","rna_v","undetect.vl")],HAARTstartdate[,c("site.patient","FirstHAARTdate")],by="site.patient")
#Sort by patient,lab date
	labrna_temp<-with(labrna_temp,labrna_temp[order(site.patient,rna_dt),])

#Time since initiation
#Restrict to those labs within baseline VL window  -180 - +7 days within initiation
	labrna_temp$ART1lag<-labrna_temp$rna_dt-labrna_temp$FirstHAARTdate
	labrna_temp2<-labrna_temp[labrna_temp$ART1lag<=7 & labrna_temp$ART1lag>-181 & is.na(labrna_temp$ART1lag)==F,]
#How to choose 'best lab (per 11/11 convo with BS):
	#1 - Look for lab closest to start date BEFORE initiation
	#2 - If no lab within 180 days before initiation, take first lab within 7 days
#Create garbo variable to make this happen
#Take abs value of all variables, add 180 days to labs after initiation
#Grab the minimum
	labrna_temp2$rnawindow_temp<-abs(labrna_temp2$ART1lag)+((labrna_temp2$ART1lag)>0)*180
	BaselineVLdata<-ddply(labrna_temp2,.(site.patient), summarize, BaselineVL=max(rna_v[rnawindow_temp==min(rnawindow_temp)]),BaselineVL_lag=ART1lag[rnawindow_temp==min(rnawindow_temp)],BaselineVL_dt=rna_dt[rnawindow_temp==min(rnawindow_temp)],
	BaselineVL.Undetectable=undetect.vl[rnawindow_temp==min(rnawindow_temp)])


#19SEP2014 addition - speed up code by removing all pre-treatment VLs
	labrna_temp<-labrna_temp[labrna_temp$ART1lag>0,]
	labrna_temp<-labrna_temp[is.na(labrna_temp$rna_v)==F & is.na(labrna_temp$rna_dt)==F ,]

#19SEP2014
#Altered loop such that patient ID comparison occurs outside loop (rather than comparing [i] to [i-1] for each observation)
#Drammatically improves speed
	labrna_temp$PreviousID<-c("NA",as.character(labrna_temp$site.patient[1:(dim(labrna_temp)[1]-1)]))
	labrna_temp$Newobs<-labrna_temp$site.patient!=labrna_temp$PreviousID


#Define VL Failure
	VLFailure<-rep("",dim(labrna_temp)[1])
	VLEverBelow400<-0
	VLAbove400Consecutive<-0
	for (i in 1:dim(labrna_temp)[1]){
	    if (labrna_temp$Newobs[i]==TRUE){
	        VLFailure[i]<-""
	        VLEverBelow400<-0
	        VLAbove400Consecutive<-0
	    }
    
	    else VLFailure[i]<-VLFailure[i-1]
    
	    if (VLFailure[i]==""){
	        if (labrna_temp$rna_v[i]<=400) {
	            VLEverBelow400<-1
	            VLAbove400Consecutive<-0
	        }
	        else if (labrna_temp$rna_v[i]>400 & VLEverBelow400==0  & labrna_temp$ART1lag[i]>180) VLFailure[i]<-"Definition 1"
	        else if (labrna_temp$rna_v[i]>1000& VLEverBelow400==1 ) VLFailure[i]<-"Definition 3"
	        else if (labrna_temp$rna_v[i]>400 & VLEverBelow400==1 ) {
	            VLAbove400Consecutive<-1+VLAbove400Consecutive
	            if (VLAbove400Consecutive==2) VLFailure[i]<-"Definition 2"
	        }
        
	    }
	}

#For the patients with a failure, find the first instance
	labrna_temp$VLFailure<-VLFailure
	labrna_justfailures<-labrna_temp[labrna_temp$VLFailure!="" ,]
	TimetoFailureData_temp1<-ddply(labrna_justfailures,.(site.patient), summarize, VLFailure=VLFailure[ART1lag==min(ART1lag)],VLFailure_time=ART1lag[ART1lag==min(ART1lag)],VLFailure_dt=rna_dt[ART1lag==min(ART1lag)])

#For those without a failure who had a VL after starting ART, find the time of the last measurement
	labrna_lastobs<-labrna_temp[labrna_temp$ART1lag>0 & is.na(labrna_temp$rna_v)==F & is.na(labrna_temp$ART1lag)==F,]
	labrna_lastobs2<-ddply(labrna_lastobs,.(site.patient), summarize, VLFailure=VLFailure[ART1lag==max(ART1lag)],VLFailure_time=ART1lag[ART1lag==max(ART1lag)],VLFailure_dt=rna_dt[ART1lag==max(ART1lag)])
	TimetoNonFailureData<-labrna_lastobs2[labrna_lastobs2$VLFailure=="",]
	TimetoNonFailureData$VLFailure<-"No Failure"

	TimetoFailureData<-rbind(TimetoFailureData_temp1,TimetoNonFailureData)
                     
                                        




#10SEP2014
#Censoring patients with infrequent VLs
#Create a window that a patient has to have a VL within a certain time period or they get censored
#Censor at the last acceptable observation

    censorwindow<-365

#############################
#Preliminary (crude) step to create a column of last recorded VL date
#Note that due to it's crudeness, we will need an additional step to make sure the dates correspond to the same patient
    previous_id<-rep(NA,length(labrna_lastobs$site.patient))
#23OCT2014 - add as.character() to change previous_id from a factor
    previous_id[2:length(previous_id)]<-as.character(labrna_lastobs$site.patient[1:(length(previous_id)-1)])

    previous_dt<-rep(NA,length(labrna_lastobs$rna_dt))
    previous_dt[2:length(previous_dt)]<-labrna_lastobs$rna_dt[1:(length(previous_dt)-1)]
#############################
#Calculate the lag between VL measurements
    labrna_lastobs$previous_datelag<-ifelse(previous_id==labrna_lastobs$site.patient,as.Date(labrna_lastobs$rna_dt)-as.Date(previous_dt,origin="1970-01-01"),NA)

    rm(previous_id,previous_dt)





#Update TimetoFailureData
#Want to remove any patients who did not have a VL measurement in Year 1
    FirstVLTime<-ddply(labrna_lastobs, .(site.patient), summarize,TimetoFirstVL=min(ART1lag))
    VLinFirst365only<-FirstVLTime[FirstVLTime$TimetoFirstVL<=365,]
    TimetoFailureData_v1<-merge(TimetoFailureData,VLinFirst365only,by="site.patient")

#VL Failure Outcome:
#This was outcome used in manuscript
#Find the first date that a patient had a lag greater than the censoring window
#Censor at gaps
#If a patient never had a 365+ day lag, they will not be included here
#We want the last VL before the 365 day lag
    NoVLs_365days <- ddply(labrna_lastobs[labrna_lastobs$previous_datelag > censorwindow & is.na(labrna_lastobs$previous_datelag)==F,], .(site.patient), summarize,LastAcceptableVLdate=min(rna_dt-previous_datelag))
    TimetoFailureData_v2<-merge(TimetoFailureData_v1,NoVLs_365days,by="site.patient",all.x=TRUE)

#Update variables
    TimetoFailureData_v2$VLFailure<-with(TimetoFailureData_v2,ifelse(VLFailure_dt > LastAcceptableVLdate & is.na(LastAcceptableVLdate)==F, "No Failure",VLFailure))
    TimetoFailureData_v2$VLFailure_time<-with(TimetoFailureData_v2,ifelse(VLFailure_dt > LastAcceptableVLdate & is.na(LastAcceptableVLdate)==F, LastAcceptableVLdate - VLFailure_dt + VLFailure_time,VLFailure_time))
    TimetoFailureData_v2$VLFailure_dt<-as.Date(with(TimetoFailureData_v2,ifelse(VLFailure_dt > LastAcceptableVLdate & is.na(LastAcceptableVLdate)==F, LastAcceptableVLdate,VLFailure_dt)),origin="1970-01-01")



#Function to determine VL at a specific timepoint AFTER HAART initiation

    PostHAARTVLs<-function(timepoint,window,label){
        window.lower<-timepoint-window
        window.upper<-timepoint+window
        
        #How to choose 'best lab' for post-HAART (Giganti)
        #Identify all labs in window of timepoint
        #Grab the closest to timepoint
        #Need to jitter it a little so that we can distinguish ties before (.99) and after (0.01) timepoint
        #In case of tie, take the lab AFTER timepoint
        labrna_temp3<-labrna_temp[labrna_temp$ART1lag<=window.upper & labrna_temp$ART1lag>window.lower & is.na(labrna_temp$ART1lag)==F,]
        labrna_temp3$vlwindow_temp1<-as.numeric((labrna_temp3$ART1lag - timepoint))
        labrna_temp3$vlwindow_temp<-as.numeric(abs(labrna_temp3$ART1lag - timepoint+.01))
        
        WindowVLdata<-ddply(labrna_temp3,.(site.patient), summarize, WindowVL=(rna_v[vlwindow_temp==min(vlwindow_temp)]),WindowVL_lag=(vlwindow_temp1[vlwindow_temp==min(vlwindow_temp)]),
            VL.Undetectable=undetect.vl[vlwindow_temp==min(vlwindow_temp)])

        names(WindowVLdata)<-c("site.patient",label,paste(label,".lag",sep=""),paste(label,".undetectable",sep=""))
        return(WindowVLdata)
    }



#VLs at 6,12,24 months
    VL.at.6months<-PostHAARTVLs(timepoint=180,window=90,label="VL.6")
    VL.at.12months<-PostHAARTVLs(timepoint=365,window=90,label="VL.12")
    VL.at.24months<-PostHAARTVLs(timepoint=730,window=90,label="VL.24")
    VL.PostBaseline_temp<-merge(VL.at.6months,VL.at.12months,by="site.patient",all=T)
    VL.PostBaseline<-merge(VL.PostBaseline_temp,VL.at.24months,by="site.patient",all=T)



###############################################################################
###############################################################################
#Begin process of merging seperate datasets together to create analysis dataset
#R only allows merging one at a time
###############################################################################
###############################################################################

	temp1<-basic[,c("site.patient","patient","site","male","mode","birth_dt","hivdiagnosis_d","hivdiagnosis_d_a","baseline_dt","aids_y","aids_cl_y","recart_y","center")]
	temp2<-merge(temp1,ARTSummaryData,by="site.patient",all=T)
	temp3<-merge(temp2,BaselineCD4data,by="site.patient",all=T)
	temp4<-merge(temp3,nadirCD4data,by="site.patient",all=T)
	temp5<-merge(temp4,follow.short,by="site.patient",all=T)
	temp6<-merge(temp5,BaselineVLdata,by="site.patient",all=T)
	temp7<-merge(temp6,TimetoFailureData_v2,by="site.patient",all=T)
	temp8<-merge(temp7,AIDSstatus,by=c("site.patient","site","patient"),all=T)
	temp9<-merge(temp8,CD4.PostBaseline,by="site.patient",all=T)
    temp10<-merge(temp9,VL.PostBaseline,by="site.patient",all=T)
    Preliminary<-temp10


#Create analysis variables
#age at ART initiation
	Preliminary$age<-as.numeric(floor((Preliminary$FirstHAARTdate-Preliminary$birth_dt)/365.25))
    Preliminary$age50<-as.numeric(Preliminary$age>=50)
#Convert Baseline VLs to log scale
#Be very cautious with this variable.   Most undetectables are coded as "- xx", so the absolute values are intended to remove these negatives.  By taking the absolute value (and then the log10), we mask this.   Currently, this does not impact the median/IQR values but should be monitored.
	Preliminary$BaselinelogVL<-log10(abs(Preliminary$BaselineVL))
	Preliminary$nadirCD4cat<-with(Preliminary,ifelse(nadirCD4<=200 & is.na(nadirCD4)==F,"LT 200",
	                            ifelse(nadirCD4>200 & abs(nadirCD4_lag)<=180 & is.na(nadirCD4)==F & is.na(nadirCD4_lag)==F,"GT 200",
	                            "Unknown")))
                                  
	Preliminary$aids.initiation<-ifelse(Preliminary$preARTAIDS.clinical=="AIDS",1,ifelse(Preliminary$preARTAIDS.clinical=="not AIDS",0,NA))
	Preliminary$aids.initiation.all<-ifelse(Preliminary$preARTAIDS.all=="AIDS",1,ifelse(Preliminary$preARTAIDS.all=="not AIDS",0,NA))


	Preliminary$HAART.time<-as.numeric(Preliminary$censor_dt-Preliminary$FirstHAARTdate)

	
	#18AUG2015
    #Some HIV diagnsosis dates lack precision.
    #Re-coded the diagnosis date to the beginning of the month/year.
	#This will systemtatically increase the window from diagnosis to HAART initiation

	Preliminary$hivdiagnosis_dt<-as.Date(Preliminary$hivdiagnosis_d)
	Preliminary$hivdiagnosis_dt<-as.Date(with(Preliminary,ifelse(toupper(hivdiagnosis_d_a) %in% c("","D"),as.character(hivdiagnosis_dt),
												  ifelse(toupper(hivdiagnosis_d_a) %in% c("M"),paste(substr(hivdiagnosis_dt,1,8),"01",sep=""),
												  ifelse(toupper(hivdiagnosis_d_a) %in% c("Y"),paste(substr(hivdiagnosis_dt,1,5),"01-01",sep=""),
												  ifelse(toupper(hivdiagnosis_d_a) %in% c("<",">","A","U"),as.character(hivdiagnosis_dt),
												  as.character(hivdiagnosis_dt)))))))

	Preliminary$hivdiagnosis_dt<-ifelse(Preliminary$hivdiagnosis_dt=="1900-01-01",NA, Preliminary$hivdiagnosis_dt)

	#18AUG2015
	#Additional effort to get DiagtoHAART time as precise as possible
	#Create a temp HAART start variable that reasigns HAART date to the LATEST possible day if they were only specified to month/year
	#Note that his only corrects about 10% of the negative values
	FirstHAARTdate_conservative<-as.Date(with(Preliminary,ifelse(toupper(FirstHAARTExact) %in% c("","D"),as.character(FirstHAARTdate),
												  ifelse(toupper(FirstHAARTExact) %in% c("M"),paste(substr(FirstHAARTdate,1,8),"28",sep=""),
												  ifelse(toupper(FirstHAARTExact) %in% c("Y"),paste(substr(FirstHAARTdate,1,5),"12-31",sep=""),
												  ifelse(toupper(FirstHAARTExact) %in% c("<",">","A","U"),as.character(FirstHAARTdate),
												  as.character(FirstHAARTdate)))))))
								

	Preliminary$DiagtoHAART.time<-as.numeric((FirstHAARTdate_conservative-Preliminary$hivdiagnosis_dt))
	#18AUG2015  Patients with negative time set to missing
	Preliminary$hivdiagnosis_dt<-ifelse(Preliminary$DiagtoHAART.time<0 & is.na(Preliminary$DiagtoHAART.time)==F,NA,as.Date(Preliminary$hivdiagnosis_dt,origin="1970-01-01"))
	Preliminary$DiagtoHAART.time<-ifelse(Preliminary$DiagtoHAART.time<0 & is.na(Preliminary$DiagtoHAART.time)==F,NA,Preliminary$DiagtoHAART.time)
	

    Preliminary$diagnosisage<-as.numeric(floor((as.Date(Preliminary$hivdiagnosis_dt,origin="1970-01-01")-Preliminary$birth_dt)/365.25))

    #10JUL2017 Replace missing ages for those without diagnosis date
    enrollage<-as.numeric(floor((as.Date(Preliminary$baseline_dt,origin="1970-01-01")-Preliminary$birth_dt)/365.25))
    Preliminary$diagnosisage<-with(Preliminary,ifelse(is.na(diagnosisage),enrollage,diagnosisage))

###################################################################################################
#Create variables to indicate first HAART stoppage, first treatment interuption, and first change
###################################################################################################

#HAART first stop
#Does not incorporate stop reason
#Right now, some patients are getting censored at their last visit.  However, these patients may be at their last visit because they are stopped!
    Preliminary$HAARTFirstStop<-with(Preliminary,
    ifelse(is.na(censor_dt),NA,
    ifelse(is.na(HAARTFirstStop_dt),0,
    ifelse(FirstStopIndicator%in%c("ImmediateRegimenSwitch","DelayedRegimenSwitch","Gap"),1,
    ifelse(censor_dt>HAARTFirstStop_dt & FirstStopIndicator%in%c("No change") ,1,
    ifelse(censor_dt==HAARTFirstStop_dt & FirstStopIndicator%in%c("No change"),0,
    ifelse(censor_dt<HAARTFirstStop_dt,99,0)))))))

    Preliminary$HAARTFirstStop_dt<-as.Date(with(Preliminary,ifelse(HAARTFirstStop==0,censor_dt,HAARTFirstStop_dt)),origin="1970-01-01")

    Preliminary$HAARTFirstStop_time<-as.numeric(Preliminary$HAARTFirstStop_dt-Preliminary$FirstARTdate)


#HAART first interruption
#Right now, some patients are getting censored at their last visit.  However, these patients may be at their last visit because they are interrupted!
#Currently do not require interruption of ART to imply an eventual resumption of ART
    Preliminary$HAARTFirstInterrupt<-with(Preliminary,
    ifelse(is.na(censor_dt),NA,
    ifelse(is.na(HAARTFirstInterrupt_dt),0,
    ifelse(FirstInterruptIndicator%in%c("DelayedRegimenSwitch","Gap"),1,
    ifelse(censor_dt>(HAARTFirstInterrupt_dt+14) & FirstInterruptIndicator%in%c("No change") ,1, #(~2% fall into this group)
    ifelse(censor_dt==HAARTFirstInterrupt_dt & FirstInterruptIndicator%in%c("No change"),0,
    ifelse(censor_dt<(HAARTFirstInterrupt_dt+14),0,0)))))))

    Preliminary$HAARTFirstInterrupt_dt<-as.Date(with(Preliminary,ifelse(HAARTFirstInterrupt==0,censor_dt,HAARTFirstInterrupt_dt)),origin="1970-01-01")

    Preliminary$HAARTFirstInterrupt_time<-as.numeric(Preliminary$HAARTFirstInterrupt_dt-Preliminary$FirstARTdate)


#HAART first change
    Preliminary$HAARTFirstChange<-with(Preliminary,ifelse(is.na(HAARTFirstChange_dt)==T,0,1))
    Preliminary$HAARTFirstChange_dt<-as.Date(with(Preliminary,ifelse(is.na(HAARTFirstChange_dt)==T,censor_dt ,HAARTFirstChange_dt)),origin="1970-01-01")

    Preliminary$HAARTFirstChange_time<-as.numeric(Preliminary$HAARTFirstChange_dt-Preliminary$FirstARTdate)
##################################
##################################


#Year of HAART initiation
	Preliminary$Initiation.Year<-as.numeric(format(Preliminary$FirstHAARTdate, "%Y"))

#Mode of transmission
	Preliminary$modetransmission<-as.factor(with(Preliminary,ifelse(mode=="Heterosexual contact", "Heterosexual",
                                   ifelse(mode=="Homosexual contact"|mode=="Bisexual","Homosexual/Bisexual",
                                   ifelse(mode=="Injecting drug user", "IDU",
                                   ifelse(mode=="Homo/Bisexual and Injecting drug user", "IDU",
                                   ifelse(mode=="Heterosexual contact and Injecting drug user","IDU",
                                   ifelse(mode=="Transfusion nonhemophilia related","Other",
                                   ifelse(mode=="Perinatal" |mode=="Hemophiliac", "Other",
                                   ifelse(mode=="Other (specify in mode_oth)","Other",
                                   ifelse(mode=="Unknown","Unknown",
                                   as.character(mode))))))))))))
                                    
	Preliminary$VLFailure<-with(Preliminary,ifelse(VLFailure=="No Failure",0,
                                        ifelse(VLFailure %in% c("Definition 1","Definition 2","Definition 3"),1,NA)))

	Preliminary$VLFailure_time<-as.numeric(Preliminary$VLFailure_time)



#Compare the patients HAART start date versus their ART start date
#Here, we classify the patient as non-naive if their first art dispensation was non-HAART
	Preliminary$recart_artdata<-with(Preliminary,ifelse(is.na(FirstARTdate), NA,
												ifelse(is.na(FirstHAARTdate),99,
												ifelse(FirstARTdate == FirstHAARTdate, 0,
												ifelse(FirstARTdate != FirstHAARTdate,1, -9)))))

#Sensitivity analysis
#Exclude patients who do not have HAART regimen before freeze date AND are non-naive
	Preliminary$naive<-with(Preliminary,    ifelse(recart_y==0 & recart_artdata==0,1,
											ifelse(recart_y==1 |recart_y==9| recart_artdata==1,0,NA)))
#Save original recart_y values for internal investigations
	Preliminary$recart_y_orig<-Preliminary$recart_y
	Preliminary$recart_y<- with(Preliminary,ifelse(recart_artdata==1,1,recart_y))

#Various exclusions
#Most analyses exclude patients who are NOT on HAART.  We will do that for specific analyses, but will not do that for this step of construction analysis dataset
#Usually we restrict to adults only
#Here, we restrict if start ART before age 18
#For subsequent analyses, we may want to restrict patients diagnosed before age 18.  Here, we aren't quite that strict because (some adults may not have diagnsosis date AND may be diagnosed before 18 but not start until after).  2b just allows us to cut down dataset size a little, because sensitivity analyses unlikely to be interested in those diagnosed earlier than 18.
#Does not exclude patients with HAART initiation date before baseline date.  Some sites may start patients a few days before enrollment.  This is a large chunk of patients.  If interested in excluding such patients, may want to add a window (7 or 30 days)
    Preliminary$Exclusion<-
		with(Preliminary,
	            ifelse(birth_dt=="1900-01-01", "(2a): no birthday info",
	            ifelse(age<18 & is.na(age)==F,"(2b): Age < 18",
                ifelse(diagnosisage<18 & is.na(age)==T,"(2b): Enroll Age < 18, not ART",

                ifelse(FirstHAARTdate<as.Date(EarliestARTDate) & is.na(FirstHAARTdate)==F,"(4): ART start before 1996",
	            NA)))))




  


#Analysis dataset
	CCASAnet_Analysis<-Preliminary[is.na(Preliminary$Exclusion),]

#08JAN2018 addition - Useful for calculating age-specific mortality rates
	CCASAnet_Analysis$agestart<-(CCASAnet_Analysis$FirstHAARTdate-CCASAnet_Analysis$birth_dt)/365.25
	CCASAnet_Analysis$ageend<-(CCASAnet_Analysis$censor_dt-CCASAnet_Analysis$birth_dt)/365.25


    CCASAnet_Analysis<-CCASAnet_Analysis[,c("site.patient","site","center","male","age","agestart","ageend","age50","modetransmission","aids.initiation","aids.initiation.all","FirstHAARTclass","FirstHAARTNRTI","FirstHAARTNNRTI","FirstHAARTPI","FirstHAARTRTV","FirstHAARTOTHER","BaselineCD4","nadirCD4","BaselinelogVL","BaselineVL.Undetectable","Initiation.Year","HAART.time","death_y", "DiagtoHAART.time", "FirstHAARTdate","BaselineCD4_dt","nadirCD4_dt","censor_dt","VLFailure","VLFailure_time","VLFailure_dt","HAARTFirstStop","HAARTFirstStop_dt","HAARTFirstStop_time","HAARTFirstChange","HAARTFirstChange_dt","HAARTFirstChange_time","recart_y","naive","diagnosisage","CD4.6","CD4.12","CD4.24","VL.6.undetectable","VL.12.undetectable","VL.24.undetectable")]
    colnames(CCASAnet_Analysis)<-c("site.patient","site","center","male","age","agestart","ageend","age50","modetransmission","aids.initiation","aids.initiation.all","FirstHAARTclass","FirstHAARTNRTI","FirstHAARTNNRTI","FirstHAARTPI","FirstHAARTRTV","FirstHAARTOTHER","BaselineCD4","nadirCD4","BaselinelogVL","BaselineVL.Undetectable","Initiation.Year","HAART.time","death_y","DiagtoHAART.time","FirstHAARTdate","BaselineCD4_dt","nadirCD4_dt","censor_dt","VLFailure","VLFailure_time","VLFailure_dt","HAARTFirstStop","HAARTFirstStop_dt","HAARTFirstStop_time","HAARTFirstChange","HAARTFirstChange_dt","HAARTFirstChange_time","recart_y","naive","diagnosisage","CD4.6","CD4.12","CD4.24","VL.6.undetectable","VL.12.undetectable","VL.24.undetectable")


	save(CCASAnet_Analysis,file="Over50DataCCASAnet.Rda")


#Check what the last observation date is by site
    CensorDate_bysite<-ddply(follow,.(site), summarize, site_censor_dt=max(lastalive_dt))
    CensorDate_bysite

 

